import{n as s,r as t,O as i,j as d,a$ as c,b0 as e,M as l}from"./index.BEHais2d.js";const g=s("iframe",{target:"e3tg43n0"})(({theme:o,disableScrolling:n})=>({width:"100%",colorScheme:"normal",border:"none",padding:o.spacing.none,margin:o.spacing.none,overflow:n?"hidden":void 0}));function r(o){return l(o)||o===""?void 0:o}function I({element:o}){const n=r(o.src),a=i(n)?void 0:r(o.srcdoc);return d(g,{className:"stIFrame","data-testid":"stIFrame",allow:e,disableScrolling:!o.scrolling,src:n,srcDoc:a,height:o.height,scrolling:o.scrolling?"auto":"no",sandbox:c,title:"st.iframe",tabIndex:o.tabIndex??void 0})}const m=t.memo(I);export{m as default};
